@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * element.h 
  *
- * Copyright (C) 2002-2005
+ * Copyright (C) 2002-2006
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -121,6 +121,9 @@ public:
 	
 	Before calling this function, the following fields in the GcuElectronegativity structure must be filled:
 	- Z: the atomic number, mandatory
+	- type: the gcu_radius_type, mandatory
+	- charge: the charge of the atom, mandatory; must be 0 for non ionic radii
+	and non null for ionic radii.
 	- scale: the name of the scale (e.g. "Pauling") or NULL
 	
 	The programs searches an electronegativity value for the element in the scale if given. If one is found
@@ -225,10 +228,29 @@ public:
 	element.
 	*/
 	IsotopicPattern *GetIsotopicPattern (unsigned natoms);
+	/*!
+	@return the fundamental electronic configuration for the element. The
+	returned string is formated as a pango markup, with electron numbers
+	for each sublevel as superscript.
+	*/
 	string const& GetElectronicConfiguration () {return ElecConfig;}
+	/*!
+	@return the map of known names for the element indexed by language.
+	*/
 	map<string, string> const& GetNames () {return names;}
-	GcuDimensionalValue const *GetIonizationEnergy (int rank = 1);
-	GcuDimensionalValue const *GetElectronAffinity (int rank = 1);
+	/*!
+	@param rank: the rank of the ionization.
+
+	@return the requested ionization energy as a &GcuDimensionalValue.
+	*/
+	GcuDimensionalValue const *GetIonizationEnergy (unsigned rank = 1);
+	/*!
+	@param rank: the rank of the electron affinity.
+
+	@return the requested electron affinity as a &GcuDimensionalValue.
+	For most elements, only the first is known.
+	*/
+	GcuDimensionalValue const *GetElectronAffinity (unsigned rank = 1);
 
 private:
 	unsigned char m_Z, m_nve, m_tve, m_maxve;
@@ -244,6 +266,8 @@ private:
 	vector<GcuElectronegativity*> m_en;
 	vector<Isotope*> m_isotopes;
 	vector<IsotopicPattern*> m_patterns;
+	vector<GcuDimensionalValue> m_ei;
+	vector<GcuDimensionalValue> m_ae;
 	map<string, string> names;
 	string ElecConfig;
 };
