@@ -2,24 +2,24 @@
  * Gnome Chemisty Utils
  * gtkchem3dviewer.h 
  *
- * Copyright (C) 2003-2004
+ * Copyright (C) 2003-2006
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or 
+ * modify it under the terms of the GNU General Public License as 
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA
  */
 
 
@@ -29,6 +29,7 @@
 //#include <gtkgl/gtkglarea.h>
 #include <gtk/gtkbin.h>
 #include <libxml/tree.h>
+#include <libgnomeprint/gnome-print.h>
 
 G_BEGIN_DECLS
 
@@ -66,7 +67,7 @@ GType gtk_display3d_get_type (void);
  Test programs are available in the tests directory of the Gnome Chemistry Utils source archive (sources in testgtkchem3dviewer.c
 for the use of the widget and in testbonobocontrol.c for the use of the Bonobo control).
 <hr>
-<<h2>Properties</h2>
+<h2>Properties</h2>
 There are two properties:
 - "display3d": Display3DMode (Read / Write).
 	<br>This property is used to set the display mode. When using the Bonobo control, a string is used instead the enumeration.
@@ -79,17 +80,6 @@ There are two properties:
 	
 - "bgcolor": gchar* (Read / Write).
 	<br>The background color for the display, for example "black" or "#ffffe6".
-.
-To set one of these properties when using the Bonobo control, use the associated Bonobo_PropertyBag. Example
-where control is an already existing BonoboControl widget (without error checking):
-\code
-BonoboControlFrame *control_frame;
-Bonobo_PropertyBag prop_bag;
-control_frame = bonobo_widget_get_control_frame(BONOBO_WIDGET(control));
-prop_bag = bonobo_control_frame_get_control_property_bag (control_frame, NULL);
-bonobo_pbclient_set_string (prop_bag, "display3d", "ball&stick", NULL);
-\endcode
-<hr>
 <h2>Functions</h2>
 
 Functions related to the GtkChem3DViewer Widget are described in the gtkchem3dviewer.h page.
@@ -119,24 +109,43 @@ GType               gtk_chem3d_viewer_get_type          (void) G_GNUC_CONST;
 
 Creates a GtkChem3DViewer widget and fills it with the data from uri. If uri is NULL, the widget will be empty.
 */
-GtkWidget*            gtk_chem3d_viewer_new               (gchar* uri);
+GtkWidget*            gtk_chem3d_viewer_new               (const gchar* uri);
 /*!
 @param viewer: a pointer to GtkChem3DViewer widget.
 @param uri: the URI of the file containing the molecular structure to display. Any file supported by
+@param mime_type: the mime_type of the data. Any type supported by
 <a href="http://openbabel.sourceforge.net">OpenBabel</a> may be used.
 
 Changes the molecule displayed by the one described in the uri. Nothing happens if uri is NULL.
 */
-void	gtk_chem3d_viewer_set_uri	(GtkChem3DViewer * viewer, gchar* uri);
+void	gtk_chem3d_viewer_set_uri_with_mime_type	(GtkChem3DViewer * viewer, const gchar * uri, const gchar* mime_type);
+/*!
+@param viewer: a pointer to GtkChem3DViewer widget.
+@param uri: the URI of the file containing the molecular structure to display.
+<a href="http://openbabel.sourceforge.net">OpenBabel</a> may be used.
+
+Changes the molecule displayed by the one described in the uri. Nothing happens if uri is NULL.
+*/
+void	gtk_chem3d_viewer_set_uri	(GtkChem3DViewer * viewer, const gchar * uri);
 /*!
 @param viewer: a pointer to GtkChem3DViewer widget.
 @param data: a pointer to the raw data representing a serialized version of molecule to display
-@param mime_type: the URI of the representation of the molecular structure to display. Any type supported by
+@param mime_type: the mime_type of the data. Any type supported by
 <a href="http://openbabel.sourceforge.net">OpenBabel</a> may be used.
 
 Changes the molecule displayed by the one described in the data. Nothing happens if data or mime-type is NULL.
 */
-void	gtk_chem3d_viewer_set_data	(GtkChem3DViewer * viewer, const gchar* data, const gchar* mime_type);
+void	gtk_chem3d_viewer_set_data	(GtkChem3DViewer * viewer, const gchar * data, const gchar* mime_type);
+
+/*!
+@param viewer: a pointer to GtkChem3DViewer widget.
+@param pc: a pointer to the GnomePrintContext.
+@param width: the width of the rectangle.
+@param height: the height of the rectangle.
+
+Prints the scene to a GnomePrintContext using a 300 dpi resolution.
+*/
+void gtk_chem3d_viewer_print(GtkChem3DViewer * viewer, GnomePrintContext *pc, gdouble width, gdouble height);
 
 G_END_DECLS
 
